def solve(s):
    return s.solve()


def digit_sum(s):
    return s.digit_sum()


def digit_product(s):
    """
    Returns the product of the digits
    :param s:
    :return:
    """
    return s.digit_product()
